# Asgardeo App Extensions.

|  Branch |Build Status | GitHub CI Status | HotFix Status |
| :------------ |:------------- |:------------- |:-------------
| master      | [![Build Status](https://wso2.org/jenkins/buildStatus/icon?job=iam-cloud%2Fasgardeo-app-extensions)](https://wso2.org/jenkins/job/iam-cloud/job/asgardeo-app-extensions/) | ![PR Builder](https://github.com/wso2-enterprise/asgardeo-app-extensions/workflows/PR%20Builder/badge.svg)| [![HotFix Status](https://wso2.org/jenkins/buildStatus/icon?job=iam-cloud%2Fasgardeo-app-extensions-hotfix)](https://wso2.org/jenkins/job/iam-cloud/job/asgardeo-app-extensions-hotfix/) |

Contains extensions which are applied on top of the parent [Identity Apps](https://github.com/wso2/identity-apps) respository to be used with [Asgardeo](https://github.com/wso2-enterprise/asgardeo-product).

### Setup Development Environment

1. Install NodeJS LTS(Latest Stable Version) from [https://nodejs.org/en/download/](https://nodejs.org/en/download/).
2. Instal the latest version of [pnpm](https://pnpm.io/).

    ```shell
    npm install -g pnpm@latest
    ```

    Or, follow the other [recommended installation options](https://pnpm.io/installation).

3. Install Maven from [https://maven.apache.org/download.cgi](https://maven.apache.org/download.cgi).
4. Install JDK 11 [https://www.openlogic.com/openjdk-downloads](https://www.openlogic.com/openjdk-downloads).

## Build & Run

###  Build

1. Download or clone the project source code from [https://github.com/wso2-enterprise/asgardeo-app-extensions](https://github.com/wso2-enterprise/asgardeo-app-extensions).
2. Run `mvn clean install` from the command line in the project root directory (where the root `pom.xml` is located).

The final bundled archives will be located at `distrubutions/<APP>/target/identity-<APP>-v1.**-SNAPSHOT.war`.

### Run

Go through our [guide](./docs/develop/run/README.md) to setup the runtime.

## Development

### Adding a new extension
- Step 1
Add a new self explanatory named folder to the following path.
`app-extensions/console/src/extensions/components`

- Step 2
Add a new entry to the `config.js` located inside the `extensions` folder.


    module.exports = () => {
        return {
            sections: {
                components: {
                    "feedback-button": "./components/feedback/feedback.tsx"
    				// New entry of the extension with the path to the extension
                }
            }
        };

- Step 3
Add necessary extension logic inside the above created extension folder.

## Deployment

Please configure the following configuration overrides in the `deployment.toml` file.

1. Configurations for the console.
```toml
[console]
product_version.configs.productVersion = "BETA"                                 # Product version appearing in the app header.
theme = "asgardio"                                                               # Customized sub theme name.
ui.app_copyright = "Asgardeo by WSO2"                                            # Copyright for the footer.
ui.app_title = "Asgardeo Console"                                                # App title (Visble on the browser tab)
ui.app_name = "Console"                                                          # Name of the app appearing on the logo.
ui.product_name = "Asgardeo"                                                     # Name of the product.
route_paths.home = "/develop/getting-started"                                    # Default home path for the app. (User's will be redirected here upon successful login)
applications.developer_app.configs.path = "/develop/getting-started"             # Default page for the develop view.
applications.admin_app.configs.path = "/manage/getting-started"                  # Default page for the manage view.
general_configurations.enabled = false                                           # Hides governance connectors.
session.params.userIdleTimeOut = 90000                                           # When to timeout IDLE user sessions.
session.params.userIdleWarningTimeOut = 89980                                    # When to warn users of IDLE user session timeouts.
session.params.sessionRefreshTimeOut = 1800                                      # Session reset timeout.
session.params.checkSessionInterval = 5                                          # How frequent the check session should occur.
```

2. Configurations for the My Account.

```toml
[myaccount]
product_version.configs.productVersion = "BETA"                                 # Product version appearing in the app header.
theme = "asgardio"                                                               # Customized sub theme name.
ui.app_copyright = "Asgardeo by WSO2"                                            # Copyright for the footer.
ui.app_title = "Asgardeo Account"                                                # App title (Visble on the browser tab)
ui.app_name = "Account"                                                          # Name of the app appearing on the logo.
ui.product_name = "Asgardeo"                                                     # Name of the product.
session.params.userIdleTimeOut = 90000                                           # When to timeout IDLE user sessions.
session.params.userIdleWarningTimeOut = 89980                                    # When to warn users of IDLE user session timeouts.
session.params.sessionRefreshTimeOut = 1800                                      # Session reset timeout.
session.params.checkSessionInterval = 5                                          # How frequent the check session should occur.
```

## Troubleshoot

Refer to [docs/TROUBLESHOOTING.md](docs/TROUBLESHOOTING.md)

## Contributing

### Sending Pull Requests

We are using GitHub actions to trigger builds for PRs and it has to be done on-demand.

If you need to trigger a build for your PR, add `trigger-pr-builder` as a label.

:bulb: Note: Only run the PR builder for changes that affect the compilation. Do not run the builder on README changes etc.

## Development

Refer to [docs/DEVELOPER.md](docs/DEVELOPER.md)